@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-# Copyright (c) 2002 - 2015 Detlev Offenbach <detlev@die-offenbachs.de>
+# Copyright (c) 2002 - 2016 Detlev Offenbach <detlev@die-offenbachs.de>
 #
 
 """
@@ -125,6 +125,7 @@ class DebugUI(QObject):
         debugServer.clientExit.connect(self.__clientExit)
         debugServer.clientSyntaxError.connect(self.__clientSyntaxError)
         debugServer.clientException.connect(self.__clientException)
+        debugServer.clientSignal.connect(self.__clientSignal)
         debugServer.clientVariables.connect(self.__clientVariables)
         debugServer.clientVariable.connect(self.__clientVariable)
         debugServer.clientBreakConditionError.connect(
@@ -1101,7 +1102,6 @@ class DebugUI(QObject):
         @param stackTrace list of stack entries (list of string)
         """
         self.ui.raise_()
-        self.ui.activateWindow()
         QApplication.processEvents()
         if exceptionType is None:
             E5MessageBox.critical(
@@ -1131,6 +1131,7 @@ class DebugUI(QObject):
                     self.viewmanager.setFileLine(
                         stackTrace[0][0], stackTrace[0][1], True)
             if res != E5MessageBox.No:
+                self.ui.activateWindow()
                 if Preferences.getDebugger("BreakAlways"):
                     res = E5MessageBox.Yes
                 else:
@@ -1190,6 +1191,31 @@ class DebugUI(QObject):
         else:
             self.__continue()
         
+    def __clientSignal(self, message, filename, lineNo, funcName, funcArgs):
+        """
+        Private method to handle a signal generated on the client side.
+        
+        @param message message of the syntax error
+        @type str
+        @param filename translated filename of the syntax error position
+        @type str
+        @param lineNo line number of the syntax error position
+        @type int
+        @param funcName name of the function causing the signal
+        @type str
+        @param funcArgs function arguments
+        @type str
+        """
+        self.ui.raise_()
+        self.ui.activateWindow()
+        QApplication.processEvents()
+        self.viewmanager.setFileLine(filename, lineNo, True)
+        E5MessageBox.critical(
+            self.ui, Program,
+            self.tr("""<p>The program generate the signal "{0}".<br/>"""
+                    """File: <b>{1}</b>, Line: <b>{2}</b></p>""").format(
+                message, filename, lineNo))
+        
     def __clientGone(self, unplanned):
         """
         Private method to handle the disconnection of the debugger client.
@@ -1568,7 +1594,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1687,7 +1713,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1809,7 +1835,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if runProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                 
@@ -1938,7 +1964,7 @@ class DebugUI(QObject):
             
             if not doNotStart:
                 if debugProject and self.project.getProjectType() in [
-                        "E4Plugin", "E6Plugin"]:
+                        "E6Plugin"]:
                     argv = '--plugin="{0}" {1}'.format(fn, argv)
                     fn = os.path.join(getConfig('ericDir'), "eric6.py")
                     tracePython = True  # override flag because it must be true
@@ -2001,7 +2027,7 @@ class DebugUI(QObject):
         
         if not doNotStart:
             if forProject and self.project.getProjectType() in [
-                    "E4Plugin", "E6Plugin"]:
+                    "E6Plugin"]:
                 argv = '--plugin="{0}" {1}'.format(fn, argv)
                 fn = os.path.join(getConfig('ericDir'), "eric6.py")
             
